==> qcad-3.15.5.3.tgz: lib/qcad/scripts/File/OpenFile/ts/OpenFile_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>OpenFile</name>
    <message>
        <location filename="../OpenFile.js" line="+46"/>
        <source>No import filters have been found. Aborting...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Open Drawing</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Otwórz rysunek</translatorcomment>
        <translation type="unfinished">Otwórz rysunek</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>All Files</source>
        <translatorcomment>--google--
Wszystkie pliki (*.*)
Pliki Designer UI (*.%1);;Wszystkie pliki (*)
Pliki z wydanymi tłumaczeniami (*.qm)
Wszystkie pliki (*)</translatorcomment>
        <translation type="unfinished">Wszystkie pliki</translation>
    </message>
    <message>
        <source>Format:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Format:
Format:</translatorcomment>
        <translation type="obsolete">Format:</translation>
    </message>
    <message>
        <location filename="../OpenFileInit.js" line="+2"/>
        <source>&amp;Open</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
&amp;Otwórz IDE
&amp;Otwórz...</translatorcomment>
        <translation type="unfinished">&amp;Otwórz</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Open an existing drawing</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Otwórz istniejący rysunek</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/File/OpenFile/ts/OpenFile_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>OpenFile</name>
    <message>
        <location filename="../OpenFile.js" line="+46"/>
        <source>No import filters have been found. Aborting...</source>
        <translation>Nie odnaleziono filtrów importowania. Anulowanie...</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Open Drawing</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Otwórz rysunek</translatorcomment>
        <translation>Otwieranie rysunku</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>All Files</source>
        <translatorcomment>--google--
Wszystkie pliki (*.*)
Pliki Designer UI (*.%1);;Wszystkie pliki (*)
Pliki z wydanymi tłumaczeniami (*.qm)
Wszystkie pliki (*)</translatorcomment>
        <translation>Wszystkie pliki</translation>
    </message>
    <message>
        <source>Format:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Format:
Format:</translatorcomment>
        <translation type="obsolete">Format:</translation>
    </message>
    <message>
        <location filename="../OpenFileInit.js" line="+2"/>
        <source>&amp;Open</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
&amp;Otwórz IDE
&amp;Otwórz...</translatorcomment>
        <translation>&amp;Otwórz</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Open an existing drawing</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Otwiera istniejący rysunek</translation>
    </message>
</context>
</TS>
